chop.utils
==========

.. automodule:: chop.utils

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      bdot
      bmm
      bmul
      bmv
      closure
      get_func_and_jac
      init_lipschitz
      power_iteration
   
   

   
   
   

   
   
   



